/*
  File: PresentValue.m
  Authors: Eric Bergerson
  Modification History:

  Copyright (c) 1991 Objective Technologies, Inc.
  All Rights Reserved.
*/

#import <appkit/appkit.h>
#import <otikit/mathkit.h>
#import "PresentValue.h"

@implementation PresentValue

- init
{
  monitorEnabled = NO;  

  return self;
}

- appDidInit: sender
{
  return self;
}


- setRate:anObject
{
    rate = anObject;
    [rate setMinValue: 0];
    [rate setMaxValue: 500];

    return self;
}

- setPeriods:anObject
{
    periods = anObject;
    [periods setMinValue: 1];
    [periods setMaxValue: 100];

    return self;
}

- setFutureValue:anObject
{
    futureValue = anObject;
    [futureValue setMinValue: 0];
    [futureValue setMaxValue: 1000];
    return self;
}

- setProcessor: anObject
{
  id mathPipes;

  processor = anObject;
  mathPipes = [processor pipes];
  [mathPipes setDelegate: self];

  return self;
}


- setFrom: anObject
{
  from = anObject;
  [from setMinValue: 0];
  [from setMaxValue: 500];

  return self;
}

- setTo: anObject
{
  to = anObject;
  [to setMinValue: 0];
  [to setMaxValue: 500];

  return self;
}

- setGprocessor: anObject
{
  gprocessor = anObject;
  [gprocessor setDelegate: self];

  return self;
}


- presentValue:sender
{
  char buf[100];

  sprintf(buf,"PV[%lf,%lf,%lf]",
	  [futureValue doubleValue],
	  [periods doubleValue],
	  [rate doubleValue]);
  [processor setCommand: buf];
  [processor processCommand: self];

  return self;
}

- graph: sender
{
  char buf[100];
  double toV,fromV;

  toV = [to doubleValue];
  fromV = [from doubleValue];
  sprintf(buf,"Plot[PV[%lf,%lf,x], {x,%lf,%lf}]",
	  [futureValue doubleValue],
	  [periods doubleValue],
	  fromV,toV);
  [gprocessor setCommand: buf];
  [gprocessor processCommand: self];
  
  return self;
}
  

- statusDidChange: mathObj to:(int) status
{
  static id alert;
  static NXModalSession session;

  switch(status){
  case MP_SENDING:
    if([mathObj tag] == 0){
      alert = NXGetAlertPanel(NULL,
			      "Evaluating Graph, Please wait ...",
			      NULL,NULL,NULL);
      [NXApp beginModalSession: &session for:alert];
    }
    break;

  case MP_DONE:
  case MP_DIED:
    if(([mathObj tag] == 0) || ([mathObj tag] == 2)){
      [NXApp endModalSession: &session];
      [alert orderOut: self];
      NXFreeAlertPanel(alert);
    }
    break;

  default:
    break;
  }


  return self;
}

- flipMonitorEnabled: sender
{
  monitorEnabled = [sender state];

  return self;
}

  
- kernelDidMsg: (const char *) aMsg from: aMathPipes type: msgType
{
  int len;
  char buf[200];
  id text;
  char *message;
  static int count = 0;

  if(!monitorEnabled)
    return self;

  if(aMsg == (char *) NULL){
    message = "Empty Kernel Msg";
  }else{
    message = (char *) malloc(strlen(aMsg) + 1);
    strcpy(message,aMsg);
  }

  if(![monitor isVisible]){
    [monitor orderFront: self];
  }
  text = [monitorSV docView];
  len = [text textLength];
  [text setSel:len+1:len+1];
  
  
  sprintf(buf,"\n***** Msg -%3d- *****\n%80.80s",count++, message);
  [text replaceSel: buf];

  len = [text textLength];
  [text setSel:len+1:len+1];
  [text scrollSelToVisible];

  return self;
}
  
- reInitKernel: sender
{
  [initProcessor processCommand: self];
  return self;
}


- (const char *) resultErrorText
{
  return "Error";
}

@end
